@@ -4,12 +4,12 @@ from typing import Iterable, Any, List
 
 
 def in_quotes(string: str) -> str:
-    """Wrap string in quotes."""
+    """Wrap string in double quotes."""
     return f'"{string}"'
 
 
 def merge_lists(lists: Iterable[List[Any]]) -> List[Any]:
-    """Merge all iterables of lists into a single list."""
+    """Merge an iterable of lists into a single list."""
     return reduce(lambda acc, arr: acc + arr, lists, [])
 
 
